@@ -2,32 +2,40 @@ import asyncio
 import json
 import logging
 import time
+from typing import Any
 
 import websockets
 
-from b_aws_websocket_api_test.testing_manager import TestingManager
+from b_aws_websocket_api_test.testing_infrastructure import TestingInfrastructure
 
 logger = logging.getLogger(__name__)
 
 
-def test_websocket_connection() -> None:
+def test_websocket_connection(
+        stack_outputs: Any
+) -> None:
     """
     Establishes a websocket connection with an API.
     Tries to send and receive a frame.
 
     :return: No return.
     """
-    # The websocket url is created as an output from executing test infrastructure creation.
-    WS_URL = TestingManager.CLOUDFORMATION_STACK_OUTPUTS['TestWsApiUrl']
+    websocket_url = stack_outputs[TestingInfrastructure.WEBSOCKET_API_URL_KEY]
 
-    logger.info(f'Creating websocket connection with url: {WS_URL}.')
+    logger.info(f'Creating websocket connection with url: {websocket_url}.')
 
     async def hello(current_attempt: int = 0, max_attempts: int = 5, sleep_seconds: int = 2):
         if current_attempt == max_attempts:
             raise RecursionError()
 
         try:
-            async with websockets.connect(WS_URL) as websocket:
+            timeouts = dict(
+                timeout=10,
+                close_timeout=10,
+                ping_timeout=10
+            )
+
+            async with websockets.connect(websocket_url, **timeouts) as websocket:
                 await websocket.send(json.dumps(dict(action='test')))
 
                 data = await websocket.recv()
@@ -39,7 +47,6 @@ def test_websocket_connection() -> None:
 
             time.sleep(sleep_seconds)
 
-            sleep_seconds *= 1.5
             current_attempt += 1
 
             await hello(current_attempt, max_attempts, sleep_seconds)
